@@ -47,7 +47,10 @@ TRUST_DATA = {
                       'warning-color'),
     Trust.VERIFIED: ('security-high-symbolic',
                      _('Verified'),
-                     'encrypted-color')
+                     'encrypted-color'),
+    Trust.BLIND: ('security-medium-symbolic',
+                  _('Blind Trust'),
+                  'encrypted-color')
 }
 
 
@@ -75,6 +78,13 @@ class KeyDialog(Gtk.Dialog):
         path = self._plugin.local_file_path('gtk/key.ui')
         self._ui = get_builder(path)
 
+        markup = '<a href="%s">%s</a>' % (
+            'https://dev.gajim.org/gajim/gajim-plugins/-/'
+            'wikis/omemogajimplugin', _('Read more about blind trust.'))
+        self._ui.btbv_link.set_markup(markup)
+        self._ui.infobar.set_revealed(
+            self._plugin.config['SHOW_HELP_FINGERPRINTS'])
+
         self._ui.header.set_text(_('Fingerprints for %s') % self._contact.jid)
 
         omemo_img_path = self._plugin.local_file_path('omemo.png')
@@ -87,7 +97,7 @@ class KeyDialog(Gtk.Dialog):
         ownfpr_format = get_fingerprint(self._identity_key, formatted=True)
         self._ui.own_fingerprint.set_text(ownfpr_format)
 
-        self.get_content_area().add(self._ui.grid)
+        self.get_content_area().add(self._ui.box)
 
         self.update()
         self._load_qrcode()
@@ -95,6 +105,11 @@ class KeyDialog(Gtk.Dialog):
         self.connect('destroy', self._on_destroy)
         self.show_all()
 
+    def _on_infobar_response(self, _widget, response):
+        if response == Gtk.ResponseType.CLOSE:
+            self._ui.infobar.set_revealed(False)
+            self._plugin.config['SHOW_HELP_FINGERPRINTS'] = False
+
     def _filter_func(self, row, _user_data):
         search_text = self._ui.search.get_text()
         if search_text and search_text.lower() not in str(row.jid):
@@ -352,11 +367,7 @@ class TrustPopver(Gtk.Popover):
         self._row = row
         self._listbox = Gtk.ListBox()
         self._listbox.set_selection_mode(Gtk.SelectionMode.NONE)
-        if row.trust != Trust.VERIFIED:
-            self._listbox.add(VerifiedOption())
-        if row.trust != Trust.UNTRUSTED:
-            self._listbox.add(NotTrustedOption())
-        self._listbox.add(DeleteOption())
+        self.update()
         self.add(self._listbox)
         self._listbox.show_all()
         self._listbox.connect('row-activated', self._activated)
@@ -376,6 +387,8 @@ class TrustPopver(Gtk.Popover):
         self._listbox.foreach(self._listbox.remove)
         if self._row.trust != Trust.VERIFIED:
             self._listbox.add(VerifiedOption())
+        if self._row.trust != Trust.BLIND:
+            self._listbox.add(BlindOption())
         if self._row.trust != Trust.UNTRUSTED:
             self._listbox.add(NotTrustedOption())
         self._listbox.add(DeleteOption())
@@ -398,6 +411,17 @@ class MenuOption(Gtk.ListBoxRow):
         self.show_all()
 
 
+class BlindOption(MenuOption):
+
+    type_ = Trust.BLIND
+    icon = 'security-medium-symbolic'
+    label = _('Blind Trust')
+    color = 'encrypted-color'
+
+    def __init__(self):
+        MenuOption.__init__(self)
+
+
 class VerifiedOption(MenuOption):
 
     type_ = Trust.VERIFIED
