@@ -114,7 +114,11 @@ class OmemoPlugin(GajimPlugin):
         self.disabled_accounts = []
         self._windows = {}
 
-        self.config_default_values = {'DISABLED_ACCOUNTS': ([], ''), }
+        self.config_default_values = {
+            'DISABLED_ACCOUNTS': ([], ''),
+            'BLIND_TRUST': (True, ''),
+            'SHOW_HELP_FINGERPRINTS': (True, ''),
+        }
 
         for account in self.config['DISABLED_ACCOUNTS']:
             self.disabled_accounts.append(account)
